@@ -500,10 +500,6 @@ class RedfishManagement(base.ManagementInterface):
                 'line_input_voltage', 'last_power_output_watts',
                 'serial_number')
             sensor.update(cls._sensor2dict(power.status, 'state', 'health'))
-            sensor.update(cls._sensor2dict(
-                power.input_ranges, 'minimum_voltage',
-                'maximum_voltage', 'minimum_frequency_hz',
-                'maximum_frequency_hz', 'output_wattage'))
             unique_name = '%s:%s@%s' % (
                 power.identity, chassis.power.identity,
                 chassis.identity)
@@ -1344,6 +1340,18 @@ class RedfishManagement(base.ManagementInterface):
             LOG.error(msg)
             raise exception.RedfishError(error=msg)
 
+    @task_manager.require_exclusive_lock
+    def get_virtual_media(self, task):
+        """Get all virtual media devices from the node.
+
+            :param task: A task from TaskManager.
+
+        """
+        LOG.info('Called redfish.management.get_virtual_media,'
+                 'for the node=%(node)s',
+                 {'node': task.node.uuid})
+        return redfish_boot.get_vmedia(task)
+
     @task_manager.require_exclusive_lock
     def attach_virtual_media(self, task, device_type, image_url):
         """Attach a virtual media device to the node.
